@@ -3,24 +3,36 @@
 package Pinto::Exception;
 
 use Moose;
-use MooseX::MarkAsMethods (autoclean => 1);
+use Moose::Exporter;
+
+use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 #------------------------------------------------------------------------------
 
-extends qw(Throwable::Error);
+extends 'Throwable::Error';
 
 #------------------------------------------------------------------------------
 
-__PACKAGE__->meta->make_immutable;
+Moose::Exporter->setup_import_methods( as_is => [ throw => \&throw ] );
+
+#------------------------------------------------------------------------------
+# HACK: I'm not sure this will work with subclasses
+
+
+sub throw { return __PACKAGE__->SUPER::throw(@_) }
+
+#------------------------------------------------------------------------------
+
+__PACKAGE__->meta->make_immutable( inline_constructor => 0 );
 
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
@@ -32,11 +44,17 @@ Pinto::Exception - Base class for Pinto exceptions
 
 =head1 VERSION
 
-version 0.065_04
+version 0.041
+
+=head1 FUNCTIONS
+
+=head2 throw( $message )
+
+Throws an exception (of this class) with the given message.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -46,3 +64,6 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
