@@ -4,15 +4,15 @@ package Pinto::SpecFactory;
 
 use strict;
 use warnings;
-use namespace::autoclean;
 
+use Carp;
 use Class::Load;
 
-use Pinto::Util qw(throw); 
+use namespace::autoclean;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -36,7 +36,7 @@ sub make_spec {
     }
     else {
 
-      throw "Don't know how to make spec from $arg";
+      croak "Don't know how to make spec from $arg";
     }
 
     Class::Load::load_class($spec_class);
@@ -46,7 +46,7 @@ sub make_spec {
 #-------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
@@ -58,7 +58,7 @@ Pinto::SpecFactory - Create Spec objects from strings
 
 =head1 VERSION
 
-version 0.065_04
+version 0.041
 
 =head1 METHODS
 
@@ -69,7 +69,7 @@ L<Pinto::PackageSpec> object constructed from the given C<$string>.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -79,3 +79,6 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
